@@ -3,17 +3,10 @@
 
 Ssl::Config Ssl::TheConfig;
 
-Ssl::Config::Config()
-#if USE_SSL_CRTD
-        :
-        ssl_crtd(NULL)
-#endif
-{
-}
-
 Ssl::Config::~Config()
 {
 #if USE_SSL_CRTD
     xfree(ssl_crtd);
 #endif
+    xfree(ssl_crt_validator);
 }
